@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 
 sub databaseName {
@@ -173,7 +173,7 @@ sub generateScript {
             my $varlen  = length($l->[0]) ;
             my $colpadding = $widest_column_name_padding - (int(($varlen)/4));
             my $varpadding = $widest_column_name_padding - (int(($varlen+1)/4));
-            push @pk_ColumnsCheck , "($l->[0]" . "\t"x$varpadding . " = \@$l->[0]" . "\t"x$varpadding . "or ($l->[0]". "\t"x$varpadding . " is null and \@$l->[0] ". "\t"x$varpadding . " is null ) ) " ;
+            push @pk_ColumnsCheck , "([$l->[0]]" . "\t"x$varpadding . " = \@$l->[0]" . "\t"x$varpadding . "or ([$l->[0]]". "\t"x$varpadding . " is null and \@$l->[0] ". "\t"x$varpadding . " is null ) ) " ;
         }
         #my @pk_ColumnsCheck     = map { "( $_->[0]\t\t\t = \@$_->[0] or ( $_->[0]\t\t\t is null and \@$_->[0] is null ) ) " } @{$ra_columns} ;
         $primaryKeyCheckClause  = "where\t" . do { local $" = "\n\t\t\t\tand\t\t"; "@pk_ColumnsCheck" }  
@@ -185,7 +185,7 @@ sub generateScript {
             my $varlen  = length($l->[0]) ;
             my $colpadding = $widest_column_name_padding - (int(($varlen)/4));
             my $varpadding = $widest_column_name_padding - (int(($varlen+1)/4));
-            push @pk_ColumnsCheck , "($l->[0]" . "\t"x$varpadding . " = \@$l->[0]" . "\t"x$varpadding . "or ($l->[0]". "\t"x$varpadding . " is null and \@$l->[0] ". "\t"x$varpadding . " is null ) ) " ;
+            push @pk_ColumnsCheck , "([$l->[0]]" . "\t"x$varpadding . " = \@$l->[0]" . "\t"x$varpadding . "or ([$l->[0]]". "\t"x$varpadding . " is null and \@$l->[0] ". "\t"x$varpadding . " is null ) ) " ;
 
         my @reportingPKCols         = map { "$_->[0]" } @{$ra_columns} ;
         $reportingPKCols            = do {local $" = ", "; "@reportingPKCols"} ;
@@ -221,7 +221,7 @@ sub generateScript {
 
 #warn Dumper     $widest_column_name_len;
 #warn Dumper     $widest_column_name_padding;
-
+#warn Dumper @{$ra_columns};
     foreach my $l (@{$ra_columns}) {
         my $varlen  = length($l->[0]) ;
         my $colpadding = $widest_column_name_padding - (int(($varlen)/4));
@@ -229,17 +229,18 @@ sub generateScript {
 #warn Dumper     $l->[0];        
 #warn Dumper     $varlen;
 #warn Dumper     $padding;
-       
+#warn Dumper $variabledeclaration;
+#warn Dumper $varpadding;
 #        do { local $" = "\t"; $variabledeclaration      .= "@"."@{$l}[0,1,2,3,5]" ; $variabledeclaration .= "\n\t,\t\t"} ;
         do { local $" = "\t"; $variabledeclaration      .= "@"."@{$l}[0]". "\t"x$varpadding . "$$l[1]" ."@{$l}[2,3]" ; $variabledeclaration .= "\n\t,\t\t"} ;
 #        do { local $" = "\t"; $tabledeclaration         .= "@{$l}" ; $tabledeclaration .= "\n\t\t,\t"} ;
-        do { local $" = "\t"; $tabledeclaration         .= "@{$l}[0]". "\t"x$colpadding . "$$l[1]" ."@{$l}[2,3,4,5]" ; $tabledeclaration .= "\n\t,\t\t"} ;
+        do { local $" = "\t"; $tabledeclaration         .= "[@{$l}[0]]". "\t"x$colpadding . "[$$l[1]]" ."@{$l}[2,3,4,5]" ; $tabledeclaration .= "\n\t,\t\t"} ;
 #        do { local $" = "";   $selectstatement          .= "@"."$l->[0]\t\t= $l->[0]" ; $selectstatement .= "\n\t\t,\t\t"} ;
-        do { local $" = "";   $selectstatement          .= "@"."$l->[0]" . "\t"x$varpadding ."= $l->[0]" ; $selectstatement .= "\n\t\t,\t\t"} ;
-        do { local $" = "";   $insertclause             .= "$l->[0]" ; $insertclause .= ", "} ;    
-        do { local $" = "";   $valuesclause             .= "$l->[0]" ; $valuesclause .= ", "} ;    
-        do { local $" = "";   $flatcolumnlist           .= "$l->[0]" ; $flatcolumnlist .= ", "} ;
-        do { local $" = "";   $flatExtractColumnList    .= $l->[1] =~ m{\A(?:date|datetime|smalldatetime)\z}i  ? "convert(varchar(30),$l->[0],120)" :  "$l->[0]" ; $flatExtractColumnList .= ", "} ;
+        do { local $" = "";   $selectstatement          .= "@"."$l->[0]" . "\t"x$varpadding ."= [$l->[0]]" ; $selectstatement .= "\n\t\t,\t\t"} ;
+        do { local $" = "";   $insertclause             .= "[$l->[0]]" ; $insertclause .= ", "} ;    
+        do { local $" = "";   $valuesclause             .= "[$l->[0]]" ; $valuesclause .= ", "} ;    
+        do { local $" = "";   $flatcolumnlist           .= "[$l->[0]]" ; $flatcolumnlist .= ", "} ;
+        do { local $" = "";   $flatExtractColumnList    .= $l->[1] =~ m{\A(?:date|datetime|smalldatetime)\z}i  ? "convert(varchar(30),[$l->[0]],120)" :  "[$l->[0]]" ; $flatExtractColumnList .= ", "} ;
         do { local $" = "";   $flatvariablelist         .= "@"."$l->[0]" ; $flatvariablelist .= ","} ;
 
         do { local $" = "";   $printStatement           .= "'  $$l[0]: ' " ; } ;
@@ -261,6 +262,7 @@ sub generateScript {
         }
     }
 
+    
     # trim off erroneous trailing cruft - better to resign array interpolations above .
     $variabledeclaration      =~ s{ \n\t,\t\t \z }{}msx;
     $tabledeclaration         =~ s{ \n\t,\t\t \z }{}msx;
@@ -549,6 +551,8 @@ sub getCurrentTableData {
     my $pkCol        = shift ; #or croak 'no primary key' ;
     my $cols         = shift ; #or croak 'no primary key' ;
 
+#warn Dumper getCurrentTableDataSQL($combinedName,$pkCol,$cols);
+
     my $sth2 = $dbh->prepare(getCurrentTableDataSQL($combinedName,$pkCol,$cols));
     my $rs   = $sth2->execute();
     my $res  = $sth2->fetchall_arrayref() ;
@@ -728,7 +732,12 @@ select  Column_name
 ,       data_type
 ,       case when character_maximum_length is not null then '('+ case when character_maximum_length = -1 then 'max' else cast(character_maximum_length as varchar(10)) end+')' else '' end 
         as datasize
-,       case when lower(Data_type) not like '%int%' and Numeric_precision is not null then '('+cast(Numeric_precision as varchar(10))+','+cast(Numeric_scale as varchar(10))+')' else '' end 
+,       case	when lower(Data_type) = 'float'
+				then '('+cast(Numeric_precision as varchar(10))+')' 
+				when lower(Data_type) not like '%int%' and Numeric_precision is not null 
+				then '('+cast(Numeric_precision as varchar(10))+','+cast(Numeric_scale as varchar(10))+')' 
+				else '' 
+				end 
         as dataprecision
 ,       case when DATABASEPROPERTYEX(db_name(), 'Collation') != collation_name then 'collate ' + collation_name else '' end 
         as collation
